Opens the full interactive web dashboard for pre-experimental planning,
greenhouse layout generation, mixed model diagnostics, automated remedies,
publication plots, and automated scientific reports in your default web browser.
Usage
launch_app(port = NULL, launch.browser = TRUE, host = "127.0.0.1")
Arguments
- port
The TCP port that the application should listen on (optional).
- launch.browser
Logical, whether to automatically launch the default web browser (default = `TRUE`).
- host
The IPv4 address that the application should listen on (default = `"127.0.0.1"`).
Value
Runs the Shiny application. This function does not return a value until the app is closed.
Examples
if (FALSE) { # \dontrun{
# Launch the interactive GUI
launch_app()
} # }